@@ -6,8 +6,12 @@ debug = False
 msg.debug = debug
 
 
-def elbv2_ips(p: str, r: str):
-    session = boto3.session.Session(profile_name=p, region_name=r)
+def elbv2_ips(p: str, r: str): #noqa
+    if p == "from_environment":
+        session = boto3.session.Session()
+    else:
+        session = boto3.session.Session(profile_name=p, region_name=r)
+
     client = session.client('elbv2')
     list = []
 
@@ -15,14 +19,17 @@ def elbv2_ips(p: str, r: str):
     msg.info("[" + p + "]" + "[" + r + "]: ")
 
     try:
-        result = client.describe_load_balancers()
+        paginator = client.get_paginator("describe_load_balancers")
+        paginator_interator = paginator.paginate()
+        result_full = paginator_interator.build_full_result()
+        result = result_full.get('LoadBalancers')
     except botocore.errorfactory.ClientError:
         result = False
 
     if result:
         msg.hdr("Enumerating LoadBalancer v2 IPs ..")
 
-        for lb in result['LoadBalancers']:
+        for lb in result:
             i = finding()
             i.type = "elb_v2 " + lb['Type']
             i.id = lb['LoadBalancerArn']
